:mod:`npdl.layers`
==================

.. automodule:: npdl.layers

.. toctree::
    :maxdepth: 2

    layers/base
    layers/core
    layers/convolution
    layers/embedding
    layers/normalization
    layers/pooling
    layers/recurrent
    layers/shape


.. npdl/layers/base.py

.. rubric:: :doc:`layers/base`

.. autosummary::
    :nosignatures:

    Layer


.. npdl/layers/core.py

.. rubric:: :doc:`layers/core`

.. autosummary::
    :nosignatures:

    Linear
    Dense
    Softmax
    Dropout


.. npdl/layers/convolution.py

.. rubric:: :doc:`layers/convolution`

.. autosummary::
    :nosignatures:

    Convolution


.. npdl/layers/embedding.py

.. rubric:: :doc:`layers/embedding`

.. autosummary::
   :nosignatures:

    Embedding



.. npdl/layers/nomalization.py

.. rubric:: :doc:`layers/normalization`

.. autosummary::
   :nosignatures:

    BatchNormal

.. npdl/layers/pooling.py

.. rubric:: :doc:`layers/pooling`

.. autosummary::
   :nosignatures:

    MeanPooling
    MaxPooling


.. npdl/layers/recurrent.py

.. rubric:: :doc:`layers/recurrent`

.. autosummary::
   :nosignatures:

    Recurrent
    SimpleRNN
    GRU
    LSTM
    BatchLSTM

.. npdl/layers/shape.py

.. rubric:: :doc:`layers/shape`

.. autosummary::
   :nosignatures:

    Flatten
